pub fn login_redirect(ctx: &ReqCtx) -> ApiResponseExpand description
Redirect a blocked UI visitor to the right place: the MFA challenge when a second factor is still pending, otherwise the login page.
pub fn login_redirect(ctx: &ReqCtx) -> ApiResponseRedirect a blocked UI visitor to the right place: the MFA challenge when a second factor is still pending, otherwise the login page.